@@ -14,10 +14,14 @@ void gutils_shutdown (void);
 /* System and user paths */
 char const *gnm_sys_lib_dir    (void);
 char const *gnm_sys_data_dir   (void);
+char const *gnm_sys_extern_plugin_dir    (void);
 char const *gnm_icon_dir       (void);
 char const *gnm_locale_dir     (void);
 char const *gnm_usr_dir	       (gboolean versioned);
 
+gnm_float gnm_utf8_strto (const char *s, char **end);
+long gnm_utf8_strtol (const char *s, char **end);
+
 #define PLUGIN_SUBDIR "plugins"
 
 int gnm_regcomp_XL (GORegexp *preg, char const *pattern,
